# Navigator (Framework)

Navigator Framework (API) is a next-generation framework to build Asynchronous APIs.
The main goal of Navigator is to provide data sources to Navigator-Next (FrontEnd Web App).

## Quickstart ##

(TODO for installation using pip)

## Dependencies ##

 * aiohttp (Asyncio Web Framework and Server)
 * NavConfig (Configuration Management)
 * AsyncDB (Database connections)

### Getting Started ###

* Installation
* Configuration
* Database configuration
* How to run tests
* Deployment instructions

### Requirements ###

* Python >= 3.8
* asyncio (https://pypi.python.org/pypi/asyncio/)
* aiohttp >= 3.8.0

### Contribution guidelines ###

Please have a look at the Contribution Guide

* Writing tests
* Code review
* Other guidelines

### Who do I talk to? ###

* Repo owner or admin
* Other community or team contact

### License ###

Navigator is licensed under BSD license.
